@@ -190,6 +190,11 @@ def get_new_pipeline_client(organization=None):
     return connection.get_client(VSTS_MODULE + 'v5_1.build.build_client.BuildClient')
 
 
+def get_new_pipeline_client_v60(organization=None):
+    connection = get_connection(organization)
+    return connection.get_client(VSTS_MODULE + 'v6_0.pipelines.pipelines_client.PipelinesClient')
+
+
 def get_new_task_agent_client(organization=None):
     connection = get_connection(organization)
     return connection.get_client(VSTS_MODULE + 'v5_1.task_agent.task_agent_client.TaskAgentClient')
